RadioGroup<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- RadioGroup
Constructors
-
RadioGroup.builder({Key? key, required T? groupValue, required void onChanged(T?)?, required List<
T> items, required RadioButtonBuilder itemBuilder(T value), required Axis direction, required double optionHeight, required WrapAlignment horizontalAlignment, required Color activeColor, required bool toggleable, required TextStyle textStyle, required TextStyle selectedTextStyle, required EdgeInsetsGeometry textPadding, double? optionWidth, WrapCrossAlignment verticalAlignment = WrapCrossAlignment.center}) -
const
Properties
- activeColor → Color
-
final
- direction → Axis
-
final
- groupValue → T?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalAlignment → WrapAlignment
-
final
- itemBuilder → RadioButtonBuilder Function(T value)
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onChanged → void Function(T?)?
-
final
- optionHeight → double
-
final
- optionWidth → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedTextStyle → TextStyle
-
final
- textPadding → EdgeInsetsGeometry
-
final
- textStyle → TextStyle
-
final
- toggleable → bool
-
final
- verticalAlignment → WrapCrossAlignment
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited