getClip method
Returns a description of the clip given that the render object being clipped is of the given size.
Implementation
@override
Path getClip(Size size) {
final path = Path();
path.lineTo(0, 0);
path.lineTo(size.width, 0);
path.lineTo(size.width, size.height - 70);
final firstControlPoint = Offset(size.width * 0.8, size.height);
final firstEndPoint = Offset(size.width * 0.51, size.height - 90);
path.quadraticBezierTo(
firstControlPoint.dx,
firstControlPoint.dy,
firstEndPoint.dx,
firstEndPoint.dy,
);
final secondControlPoint = Offset(size.width * 0.2, size.height - 200);
final secondEndPoint = Offset(0, size.height - 122);
path.quadraticBezierTo(
secondControlPoint.dx,
secondControlPoint.dy,
secondEndPoint.dx,
secondEndPoint.dy,
);
path.close();
return path;
}